#
# spec file for package python-textfsm
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define oldpython python
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-textfsm
Version:        1.1.1
Release:        bp155.2.12
Summary:        Python module for parsing semi-structured text into python tables
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/google/textfsm
Source:         https://github.com/google/textfsm/archive/v%{version}.tar.gz#/textfsm-%{version}.tar.gz
BuildRequires:  %{python_module future}
BuildRequires:  %{python_module pytest-runner}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-future
Requires:       python-six
%ifpython2
Requires:       python-future
%endif
Conflicts:      python-texttable
BuildArch:      noarch
%ifpython2
Conflicts:      %{oldpython}-texttable
%endif
%python_subpackages

%description
Python module which implements a template based state machine for parsing
semi-formatted text. Originally developed to allow programmatic access to
information returned from the command line interface (CLI) of networking
devices.

%prep
%setup -q -n textfsm-%{version}
# drop shebang
sed -i -e '/^#!\//, 1d' textfsm/*.py

%build
%python_build

%install
%python_install
# don't install broken textfsm wrapper binary
%python_expand rm -f %{buildroot}%{_bindir}/textfsm
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license COPYING
%doc README.md
%{python_sitelib}/*

%changelog
* Tue Nov 26 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.1.1
  * Fix parsing of value string to allow mismatched parenthesis
    inside [] brackets.
  * Improve readability of value parse fix.
  * Added additional test.
  * Soft fail when fcntl is missing, fallback to default screen size.
* Thu Aug  1 2019 pgajdos@suse.com
- require future for python2
* Wed Jul 31 2019 pgajdos@suse.com
- version update to 1.1.0
  * Per 'http://python-future.org/automatic_conversion.html' py2 & py3 compatibility.
  * Make sure test fails if there is more than one list entry.
  * Fix deprecated warning for invalid escapes.
  * Support utf-8 in template files
  * Add utf-8 characters to a test example
  * Unicode example in template input.
  * Switch to utf-8 strings and remove unnecessary conversions.
  * Remove legacy lint checks
  * Migrate StringIO and remove unneeded import six.
  * Remove unnecessary explicit unicast declaration.
  * oll back changes to 'open'.
  * Cosmetic linting.
  * Package 'future' needed for importing builtins.
  * Add tests and testdata to distribution.
  * Use correct install_requires stanza for dependencies.
  * Include testdata files in binarty dist for tyesting.
- deleted patches
  - textfsm_test_do_not_relay_on_dic_order.patch (upstreamed)
* Fri Jul 20 2018 tchvatal@suse.com
- Conflict with texttable as we provide same package file
  reported on GH for upstream to sort out
* Mon Jul  2 2018 aplanas@suse.com
- Add textfsm_test_do_not_relay_on_dic_order.patch to enable
  tests in Python2 and Python3
* Thu Jun 21 2018 tchvatal@suse.com
- Add dependency over python-six as it is stated by upstream
- Switch to github archive as it contains the testdata
* Wed Jun 20 2018 gyee@suse.com
- Remove python-devel requirement as it is not needed.
* Wed Jun 20 2018 gyee@suse.com
- Remove useless descriptions.
* Wed Jun 20 2018 gyee@suse.com
- Regenerate the spec file using py2pack.
* Tue Jun 19 2018 gyee@suse.com
- Fix SingleSpec requirements.
* Tue Jun 19 2018 gyee@suse.com
- Make it a SingleSpec package.
* Mon Jun 18 2018 gyee@suse.com
- create initial package version 0.4.1:
  Pulled from https://files.pythonhosted.org/packages/a1/0d/a1b490503545b3b4600b965eae5d44cc2b6ce27cfb44f4debc563dbb56d3/textfsm-0.4.1.tar.gz
